/*
Author: Lisa Riggle
Filename: prime.cpp

This program is one in a series of programs that deals with Goldbach's Conjecture.
Goldbach's Conjecture has not been proven, nor is it likely to be by these programs,
but to further my understanding of it, and keep my C++ skills going ;), I decided
to try and program it.

This file, prime.cpp, is concerned with determining whether or not a number is,
in fact, prime.  It does this by using the modulus operator, %, and checking it against
every number between 2 and the square root of the number the user input.  If it
returns a zero, it is not a prime.
*/

#include <iostream>
#include <stdlib.h>

using namespace std;

//This function displays the results of the prime testing.
void displayResults(bool isPrime, unsigned long int number)
{
  if (isPrime)
    cout << "Congratulations! " << number << " is a prime number!\n\n";
  else
    cout << "I'm sorry, " << number << " is not a prime number.\n\n";
}  //end displayResults

//This function is the driver of the program.  It asks the user for input,
//and then initiates the prime testing.  When the testing is finished,
//the display function is called.
void checkPrimeNumber()
{
  unsigned long int checkNumber;
  cout << "Please enter the number you wish to verify: ";
  cin >> checkNumber;
  bool isPrime = true;
  unsigned long int i=2;

  while (isPrime && (i <= sqrt(checkNumber)))
  {
    if (checkNumber % i == 0)
    {
      isPrime = false;
    }  //end if
    i++;
  }  //end while

  displayResults(isPrime, checkNumber);
}  //end checkPrimeNumber

//The main function in the program initiates the checkPrimeNumber() function.
//When that function has finished running, it asks the user if they would like
//to check another number.  This will continue until the user enters the character
//assigned to "No".
void main()
{
  char doAgain;
  checkPrimeNumber();
  bool error = false;
  do
  {
    cout << "Would you like to check another number? Enter Y for Yes, N for No: ";
    cin >> doAgain;

    switch (doAgain)
    {
      case 'Y':
      case 'y':
        checkPrimeNumber();
        error = false;
        break;
      case 'N':
      case 'n':
        error = false;
        break;
      default:
        error = true;
        while (error)
        {
          cout << "I'm sorry, you entered an invalid answer.\nPlease enter Y for Yes, or N for No: ";
          cin >> doAgain;
          cout << "\n";
          if (doAgain != 'Y' && doAgain != 'y' && doAgain != 'N' && doAgain != 'n')
            error = true;
          else
            error = false;
        }
        break;
    } //end switch

  } //end do-while
  while (doAgain == 'Y' || doAgain == 'y');

  system("PAUSE");
  return 0;
}  //end main
